==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/cdk/Catalog.java <==
package io.github.cdklabs.projen.cdk;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.615Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.cdk.Catalog")
@software.amazon.jsii.Jsii.Proxy(Catalog.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface Catalog extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Should we announce new versions?
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getAnnounce() {
        return null;
    }

    /**
     * (experimental) Twitter account to @mention in announcement tweet.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getTwitter() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link Catalog}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link Catalog}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<Catalog> {
        java.lang.Boolean announce;
        java.lang.String twitter;

        /**
         * Sets the value of {@link Catalog#getAnnounce}
         * @param announce Should we announce new versions?.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder announce(java.lang.Boolean announce) {
            this.announce = announce;
            return this;
        }

        /**
         * Sets the value of {@link Catalog#getTwitter}
         * @param twitter Twitter account to @mention in announcement tweet.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder twitter(java.lang.String twitter) {
            this.twitter = twitter;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link Catalog}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public Catalog build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link Catalog}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements Catalog {
        private final java.lang.Boolean announce;
        private final java.lang.String twitter;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.announce = software.amazon.jsii.Kernel.get(this, "announce", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.twitter = software.amazon.jsii.Kernel.get(this, "twitter", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.announce = builder.announce;
            this.twitter = builder.twitter;
        }

        @Override
        public final java.lang.Boolean getAnnounce() {
            return this.announce;
        }

        @Override
        public final java.lang.String getTwitter() {
            return this.twitter;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAnnounce() != null) {
                data.set("announce", om.valueToTree(this.getAnnounce()));
            }
            if (this.getTwitter() != null) {
                data.set("twitter", om.valueToTree(this.getTwitter()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.cdk.Catalog"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Catalog.Jsii$Proxy that = (Catalog.Jsii$Proxy) o;

            if (this.announce != null ? !this.announce.equals(that.announce) : that.announce != null) return false;
            return this.twitter != null ? this.twitter.equals(that.twitter) : that.twitter == null;
        }

        @Override
        public final int hashCode() {
            int result = this.announce != null ? this.announce.hashCode() : 0;
            result = 31 * result + (this.twitter != null ? this.twitter.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/cdk/Catalog.java <==
package io.github.cdklabs.projen.cdk;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.296Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.cdk.Catalog")
@software.amazon.jsii.Jsii.Proxy(Catalog.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface Catalog extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Should we announce new versions?
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getAnnounce() {
        return null;
    }

    /**
     * (experimental) Twitter account to.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getTwitter() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link Catalog}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link Catalog}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<Catalog> {
        java.lang.Boolean announce;
        java.lang.String twitter;

        /**
         * Sets the value of {@link Catalog#getAnnounce}
         * @param announce Should we announce new versions?.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder announce(java.lang.Boolean announce) {
            this.announce = announce;
            return this;
        }

        /**
         * Sets the value of {@link Catalog#getTwitter}
         * @param twitter Twitter account to.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder twitter(java.lang.String twitter) {
            this.twitter = twitter;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link Catalog}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public Catalog build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link Catalog}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements Catalog {
        private final java.lang.Boolean announce;
        private final java.lang.String twitter;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.announce = software.amazon.jsii.Kernel.get(this, "announce", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.twitter = software.amazon.jsii.Kernel.get(this, "twitter", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.announce = builder.announce;
            this.twitter = builder.twitter;
        }

        @Override
        public final java.lang.Boolean getAnnounce() {
            return this.announce;
        }

        @Override
        public final java.lang.String getTwitter() {
            return this.twitter;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAnnounce() != null) {
                data.set("announce", om.valueToTree(this.getAnnounce()));
            }
            if (this.getTwitter() != null) {
                data.set("twitter", om.valueToTree(this.getTwitter()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.cdk.Catalog"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            Catalog.Jsii$Proxy that = (Catalog.Jsii$Proxy) o;

            if (this.announce != null ? !this.announce.equals(that.announce) : that.announce != null) return false;
            return this.twitter != null ? this.twitter.equals(that.twitter) : that.twitter == null;
        }

        @Override
        public final int hashCode() {
            int result = this.announce != null ? this.announce.hashCode() : 0;
            result = 31 * result + (this.twitter != null ? this.twitter.hashCode() : 0);
            return result;
        }
    }
}
